==> ng2-codemirror-typescript-1.1.1.tgz: package/Codemirror.ts <==
// Imports
import {NgModule, Component, Input, Output, ViewChild, EventEmitter, forwardRef} from '@angular/core';
import {NG_VALUE_ACCESSOR} from '@angular/forms';

declare var CodeMirror: any;

/**
 * CodeMirror component
 * Usage :
 * <codemirror [(ngModel)]="data" [config]="{...}"></ckeditor>
 */
@Component({
    selector: 'codemirror',
    providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => CodemirrorComponent),
            multi: true
        }
    ],
    template: `<textarea #host></textarea>`,
})
export class CodemirrorComponent {

    @Input() config;

    @Output() change = new EventEmitter();
    editor;
    @ViewChild('host') host;

    _value = '';
    @Output() instance = null;

    /**
     * Constructor
     */
    constructor() {
    }

    get value(): any {
        return this._value;
    };

    @Input() set value(v) {
        if (v !== this._value) {
            this._value = v;
            this.onChange(v);
        }
    }

    /**
     * On component destroy
     */
    ngOnDestroy() {

    }

    /**
     * On component view init
     */
    ngAfterViewInit() {
        this.config = this.config || {};
        this.codemirrorInit(this.config);
    }

    /**
     * Initialize codemirror
     */
    codemirrorInit(config) {
        this.instance = CodeMirror.fromTextArea(this.host.nativeElement, config);
        this.instance.on('change', () => {
            this.updateValue(this.instance.getValue());
        });
    }

    /**
     * Value update process
     */
    updateValue(value) {
        this.value = value;
        this.onChange(value);
        this.onTouched();
        this.change.emit(value);
    }

    /**
     * Implements ControlValueAccessor
     */
    writeValue(value) {
        this._value = value || '';
        if (this.instance) {
            this.instance.setValue(this._value);
        }
    }

    onChange(_) {
    }

    onTouched() {
    }

    registerOnChange(fn) {
        this.onChange = fn;
    }

    registerOnTouched(fn) {
        this.onTouched = fn;
    }
}

/**
 * CodemirrorModule
 */
@NgModule({
    declarations: [
        CodemirrorComponent,
    ],
    exports: [
        CodemirrorComponent,
    ]
})
export class CodemirrorModule {
}

==> ng2-codemirror-typescript-1.1.2.tgz: package/Codemirror.ts <==
// Imports
import {NgModule, Component, Input, Output, ViewChild, EventEmitter, forwardRef} from '@angular/core';
import {NG_VALUE_ACCESSOR} from '@angular/forms';

declare var CodeMirror: any;

/**
 * CodeMirror component
 * Usage :
 * <codemirror [(ngModel)]="data" [config]="{...}"></ckeditor>
 */
@Component({
    selector: 'codemirror',
    providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => CodemirrorComponent),
            multi: true
        }
    ],
    template: `<textarea [placeholder]="placeholder" #host></textarea>`,
})
export class CodemirrorComponent {

    @Input() config;
    @Input() placeholder = '';

    @Output() change = new EventEmitter();
    editor;
    @ViewChild('host') host;

    _value = '';
    @Output() instance = null;

    /**
     * Constructor
     */
    constructor() {
    }

    get value(): any {
        return this._value;
    };

    @Input() set value(v) {
        if (v !== this._value) {
            this._value = v;
            this.onChange(v);
        }
    }

    /**
     * On component destroy
     */
    ngOnDestroy() {

    }

    /**
     * On component view init
     */
    ngAfterViewInit() {
        this.config = this.config || {};
        this.codemirrorInit(this.config);
    }

    /**
     * Initialize codemirror
     */
    codemirrorInit(config) {
        this.instance = CodeMirror.fromTextArea(this.host.nativeElement, config);
        this.instance.on('change', () => {
            this.updateValue(this.instance.getValue());
        });
    }

    /**
     * Value update process
     */
    updateValue(value) {
        this.value = value;
        this.onChange(value);
        this.onTouched();
        this.change.emit(value);
    }

    /**
     * Implements ControlValueAccessor
     */
    writeValue(value) {
        this._value = value || '';
        if (this.instance) {
            this.instance.setValue(this._value);
        }
    }

    onChange(_) {
    }

    onTouched() {
    }

    registerOnChange(fn) {
        this.onChange = fn;
    }

    registerOnTouched(fn) {
        this.onTouched = fn;
    }
}

/**
 * CodemirrorModule
 */
@NgModule({
    declarations: [
        CodemirrorComponent,
    ],
    exports: [
        CodemirrorComponent,
    ]
})
export class CodemirrorModule {
}
